@@ -1,4 +1,7 @@
-import mapnik
+from mapnik_utils.version_adapter import Mapnik
+
+mapnik = Mapnik()
+
 
 class FontHandler(object):
     def __init__(self):
