@@ -1,11 +1,13 @@
 import re
 import sys
-import mapnik
+
+from mapnik_utils.version_adapter import Mapnik
+
+mapnik = Mapnik()
+
 from projection import EasyProjection
 
-try:
-    from mapnik import ProjTransform
-except:
+if not hasattr(mapnik,'ProjTransform'):
     from compatibility import ProjTransform
 
 BoostPythonMetaclass = mapnik.Coord.__class__
