@@ -1,7 +1,9 @@
 import os
 import sys
 import timeit
-import mapnik
+from mapnik_utils.version_adapter import Mapnik
+
+mapnik = Mapnik()
 
 try:
     import cairo
